<template>
	<view class="freightForwarder-my">
		<view class="fleet-container">
			<combined-title title="我的车队" @rightText="addFleet">
				<template v-slot:rightText>
					<text>添加</text>
				</template>
			</combined-title>
			<view class="fleet-list">
				<u-swipe-action>
					<u-cell-group :border="false">
						<u-swipe-action-item :options="options1" v-for="(item, index) in fleetData" :index="index" :name="item.id" :key="index" @click="deleteFleetClick">
							<u-cell :title="item.name" :value="item.userSijisum + '辆'" @click="tofleetDetails(item.id)"></u-cell>
						</u-swipe-action-item>
					</u-cell-group>
				</u-swipe-action>
			</view>
		</view>

		<!-- 新建车队弹出框 -->
		<view class="addNewGroup">
			<u-popup :show="updateGroupShow" @close="addNewFleetPopupClose" @open="addNewFleetPopupOpen" mode="center">
				<view class="title"><u--text text="新建车队" size="30" lineHeight="80" align="center"></u--text></view>
				<view class="addCarForm">
					<u--form labelPosition="left" :model="addGroupForm" ref="form1" labelAlign="center">
						<u-form-item label="组名" borderBottom ref="groupName" labelWidth="100">
							<u--input v-model="addGroupForm.name" border="none" placeholder="请输入车队名称"></u--input>
						</u-form-item>
						<!-- <u-form-item label="车牌" borderBottom ref="cars" labelWidth="80">
							<u--textarea maxlength="2000" v-model="addGroupForm.carNums" placeholder="请输入车牌" height="150"></u--textarea>
						</u-form-item> -->
					</u--form>
				</view>
				<view class="addCarButton"><u-button text="添加" type="primary" @click="addNewGroupClick"></u-button></view>
			</u-popup>
		</view>
		<view class="utils"><u-button text="退出登录" type="primary" @click="logout"></u-button></view>
		<!-- 删除车队模态框 -->
		<view class="deleteFleetModal">
			<u-modal
				:show="deleteFleetShow"
				:title="deleteFleetTitle"
				@close="deleteFleetClose"
				@cancel="deleteFleetCancel"
				@confirm="deleteFleetConfirm"
				:closeOnClickOverlay="true"
				:showCancelButton="true"
			>
				<view class="slot-content"><rich-text :nodes="deleteFleetContent"></rich-text></view>
			</u-modal>
		</view>
		<view class="logoutModel">
			<u-modal :show="logoutShow" :title="logoutTitle" showCancelButton :content="logoutContent" @confirm="logoutConfirm" @cancel="logoutCancel"></u-modal>
		</view>
	</view>
</template>

<script>
import { redirectLogin } from '@/utils/status';
export default {
	data() {
		return {
			fleetData: [],
			// 新建车队
			addGroupForm: {
				name: ''
				// wxUserId: uni.getStorageSync('userInfo').id
			},
			updateGroupShow: false,
			options1: [
				{
					text: '删除'
				}
			],
			// 删除车队模态框
			deleteFleetId: null, // 删除车队id
			deleteFleetShow: false,
			deleteFleetTitle: '',
			deleteFleetContent: '',
			// 退出模态框
			logoutShow: false,
			logoutTitle: '提示',
			logoutContent: '是否确认退出'
		};
	},
	onShow() {
		this.init();
	},
	methods: {
		init() {
			this.getFleet();
		},
		// 获取车队
		getFleet() {
			// this.$reqGet('getFleet', { wxUserId: this.addGroupForm.wxUserId }).then(res => {
			this.$reqGet('getFleet').then(res => {
				console.log('货代1车队', res);
				this.fleetData = res.data;
			});
		},
		// 添加车队
		addFleet() {
			console.log('添加车队');
			this.updateGroupShow = true;
		},
		addNewFleetPopupClose() {
			this.updateGroupShow = false;
			this.addGroupForm.name = '';
		},
		addNewFleetPopupOpen() {
			console.log('添加车队打开');
		},
		// 确认新建车队按钮
		addNewGroupClick() {
			this.updateGroupShow = false;
			this.$reqPost('saveFleet', this.addGroupForm, 'params').then(res => {
				if (res.code == 0) {
					this.$u.toast('添加成功');
					this.getFleet();
				}
			});
		},
		// 删除车队
		deleteFleetClick(args) {
			console.log(args.name, '车队id');
			this.deleteFleetId = args.name;
			this.deleteFleetShow = true;
			this.fleetData.forEach(item => {
				if (item.id == this.deleteFleetId) {
					this.deleteFleetContent = '确认删除车队' + item.name;
				}
			});
		},
		deleteFleetClose() {
			this.deleteFleetShow = false;
		},
		deleteFleetCancel() {
			this.deleteFleetShow = false;
		},
		deleteFleetConfirm() {
			this.deleteFleetShow = false;
			uni.showLoading({
				title: '加载中...'
			});
			this.$reqPost('deleteFleet', { id: this.deleteFleetId }, 'params').then(res => {
				console.log('删除车队', res);
				if (res.code == 0) {
					this.$u.toast('删除成功');
				} else {
					this.$u.toast(res.msg ? res.msg : '删除失败');
				}
				uni.hideLoading();
				this.getFleet();
			});
		},
		// 车队详情
		tofleetDetails(id) {
			uni.navigateTo({
				url: `/pages/customer-page/fleet-management/fleet-management?id=${id}`
			});
		},
		logout() {
			this.logoutShow = true;
		},
		logoutConfirm() {
			redirectLogin();
		},
		logoutCancel() {
			this.logoutShow = false;
		}
	}
};
</script>

<style lang="scss" scoped>
::v-deep.freightForwarder-my {
	width: 94%;
	margin: 0 auto;

	// 新建车队
	.addNewGroup {
		.u-popup {
			.u-popup__content {
				width: 94%;
				height: vww(160);
				border-radius: 1%;
				.title {
					width: 100%;
					text-align: center;
					font-size: 20;
					.u-text {
						.u-text__value {
						}
					}
				}
				.addCarForm {
					width: 80%;
					margin: 0 auto vww(30);
				}
				.addCarButton {
					width: 40%;
					margin: 0 auto;
					color: rgb(10, 108, 255);
				}
			}
		}
	}

	.fleet-container {
		.fleet-list {
			.u-swipe-action {
				.u-swipe-action-item {
					.u-swipe-action-item__right {
						.u-swipe-action-item__right__button {
							.u-swipe-action-item__right__button__wrapper {
								background-color: #f56c6c !important;
							}
						}
					}
				}
			}
		}
	}
}
</style>
